<div align=left>
Basic Python Programs that you need

- oddOrEven()

- isEven()
- isOdd()
- isPrime()

- isEvenNumberExist()
- isOddNumberExist()
- isPrimeNumberExist()

- getEvenNumbers()
- getOddNumbers()
- getPrimeNumbers()

- getEvenNumbersInRange()
- getOddNumbersInRange()
- getPrimeNumbersInRange()

- getEvenValues()
- getOddValues()

- isLeapYear()
- daysInMonth()
- bmi()
- fizzBuzz()
- fibonacci()
- factorial()
- isArmstrong()

- swap()


is the anything missed? <a href="https://github.com/Yaseen549/pygrams/issues/new">Raise an Issue</a>.

### Contribution Guide
1. Fork the Repo.
2. clone the Repo. (git clone REPO)
3. Create a new remote for the upstream repository. (git remote add upstream REPO)
4. Create a new branch. (git checkout -b my-branch)
5. Add Codes (git add .)
6. commit your changes. (git commit -m "Adding an awesome feature to my-branch")
7. Push the changes to your repository. (git push -u origin my-branch)
8. Create a pull request. (We will review it ASAP)

### Feature Request Process
- Title: Program Name
- Description: Add the description how the function works or
- Write the complete program and the comments which explains the program
<a href="https://github.com/Yaseen549/pygrams/issues/new">Request here</a>
</div>